EXPORTS
	??0CShowInfo@@QAE@PAV0@@Z @ 1 NONAME ; CShowInfo::CShowInfo(class CShowInfo *)
	??1CFeedInfo@@UAE@XZ @ 2 NONAME ; CFeedInfo::~CFeedInfo(void)
	??1CImageHandler@@UAE@XZ @ 3 NONAME ; CImageHandler::~CImageHandler(void)
	??1CPodcastModel@@UAE@XZ @ 4 NONAME ; CPodcastModel::~CPodcastModel(void)
	??1CShowEngine@@UAE@XZ @ 5 NONAME ; CShowEngine::~CShowEngine(void)
	??1CShowInfo@@UAE@XZ @ 6 NONAME ; CShowInfo::~CShowInfo(void)
	?ActiveClientUid@CFeedEngine@@QAEIXZ @ 7 NONAME ; unsigned int CFeedEngine::ActiveClientUid(void)
	?ActiveFeedInfo@CPodcastModel@@QAEPAVCFeedInfo@@XZ @ 8 NONAME ; class CFeedInfo * CPodcastModel::ActiveFeedInfo(void)
	?ActiveShowList@CPodcastModel@@QAEAAV?$RPointerArray@VCShowInfo@@@@XZ @ 9 NONAME ; class RPointerArray<class CShowInfo> & CPodcastModel::ActiveShowList(void)
	?AddDownloadL@CShowEngine@@QAEXAAVCShowInfo@@@Z @ 10 NONAME ; void CShowEngine::AddDownloadL(class CShowInfo &)
	?AddFeedL@CFeedEngine@@QAEHABVCFeedInfo@@@Z @ 11 NONAME ; int CFeedEngine::AddFeedL(class CFeedInfo const &)
	?AddObserver@CFeedEngine@@QAEXPAVMFeedEngineObserver@@@Z @ 12 NONAME ; void CFeedEngine::AddObserver(class MFeedEngineObserver *)
	?AddObserver@CShowEngine@@QAEXPAVMShowEngineObserver@@@Z @ 13 NONAME ; void CShowEngine::AddObserver(class MShowEngineObserver *)
	?AddObserver@CSoundEngine@@QAEXPAVMSoundEngineObserver@@@Z @ 14 NONAME ; void CSoundEngine::AddObserver(class MSoundEngineObserver *)
	?AddSearchResultL@CFeedEngine@@QAEXPAVCFeedInfo@@@Z @ 15 NONAME ; void CFeedEngine::AddSearchResultL(class CFeedInfo *)
	?AddShowL@CShowEngine@@QAEHABVCShowInfo@@@Z @ 16 NONAME ; int CShowEngine::AddShowL(class CShowInfo const &)
	?BaseDir@CSettingsEngine@@QAEAAV?$TBuf@$0BAA@@@XZ @ 17 NONAME ; class TBuf<256> & CSettingsEngine::BaseDir(void)
	?BuildDate@CFeedInfo@@QBE?AVTTime@@XZ @ 18 NONAME ; class TTime CFeedInfo::BuildDate(void) const
	?CancelUpdateAllFeeds@CFeedEngine@@QAEXXZ @ 19 NONAME ; void CFeedEngine::CancelUpdateAllFeeds(void)
	?CleanHtmlL@PodcastUtils@@SAXAAVTDes16@@@Z @ 20 NONAME ; void PodcastUtils::CleanHtmlL(class TDes16 &)
	?ClientState@CFeedEngine@@QAE?AW4TClientState@@XZ @ 21 NONAME ; enum TClientState CFeedEngine::ClientState(void)
	?ConnectionEngine@CPodcastModel@@QAEAAVCConnectionEngine@@XZ @ 22 NONAME ; class CConnectionEngine & CPodcastModel::ConnectionEngine(void)
	?CopyL@CFeedInfo@@QBEPAV1@XZ @ 23 NONAME ; class CFeedInfo * CFeedInfo::CopyL(void) const
	?CustomTitle@CFeedInfo@@QBEHXZ @ 24 NONAME ; int CFeedInfo::CustomTitle(void) const
	?DBGetShowByFileNameL@CShowEngine@@QAEPAVCShowInfo@@V?$TBuf@$0BAA@@@@Z @ 25 NONAME ; class CShowInfo * CShowEngine::DBGetShowByFileNameL(class TBuf<256>)
	?DeleteAllShowsByFeedL@CShowEngine@@QAEXIH@Z @ 26 NONAME ; void CShowEngine::DeleteAllShowsByFeedL(unsigned int, int)
	?DeleteOldShowsByFeed@CShowEngine@@QAEXI@Z @ 27 NONAME ; void CShowEngine::DeleteOldShowsByFeed(unsigned int)
	?DeletePlayedShows@CShowEngine@@QAEXAAV?$RPointerArray@VCShowInfo@@@@@Z @ 28 NONAME ; void CShowEngine::DeletePlayedShows(class RPointerArray<class CShowInfo> &)
	?DeleteShowL@CShowEngine@@QAEXIH@Z @ 29 NONAME ; void CShowEngine::DeleteShowL(unsigned int, int)
	?Description@CFeedInfo@@QBEABVTDesC16@@XZ @ 30 NONAME ; class TDesC16 const & CFeedInfo::Description(void) const
	?Description@CShowInfo@@QBEABVTDesC16@@XZ @ 31 NONAME ; class TDesC16 const & CShowInfo::Description(void) const
	?DownloadAutomatically@CSettingsEngine@@QAEHXZ @ 32 NONAME ; int CSettingsEngine::DownloadAutomatically(void)
	?DownloadState@CShowInfo@@QBE?AW4TDownloadState@@XZ @ 33 NONAME ; enum TDownloadState CShowInfo::DownloadState(void) const
	?DownloadSuspended@CSettingsEngine@@QAEHXZ @ 34 NONAME ; int CSettingsEngine::DownloadSuspended(void)
	?EnsureProperPathName@PodcastUtils@@SAXAAV?$TBuf@$0BAA@@@@Z @ 35 NONAME ; void PodcastUtils::EnsureProperPathName(class TBuf<256> &)
	?ExportFeedsL@CFeedEngine@@QAEHAAV?$TBuf@$0BAA@@@@Z @ 36 NONAME ; int CFeedEngine::ExportFeedsL(class TBuf<256> &)
	?FeedEngine@CPodcastModel@@QAEAAVCFeedEngine@@XZ @ 37 NONAME ; class CFeedEngine & CPodcastModel::FeedEngine(void)
	?FeedIcon@CFeedInfo@@QBEPAVCFbsBitmap@@XZ @ 38 NONAME ; class CFbsBitmap * CFeedInfo::FeedIcon(void) const
	?AddObserver@CConnectionEngine@@QAEXPAVMConnectionObserver@@@Z @ 39 NONAME ; void CConnectionEngine::AddObserver(class MConnectionObserver *)
	?FeedUid@CShowInfo@@QBEIXZ @ 40 NONAME ; unsigned int CShowInfo::FeedUid(void) const
	?FileName@CShowInfo@@QBEABVTDesC16@@XZ @ 41 NONAME ; class TDesC16 const & CShowInfo::FileName(void) const
	?FileNameFromUrl@PodcastUtils@@SAXABVTDesC16@@AAV?$TBuf@$0BAA@@@@Z @ 42 NONAME ; void PodcastUtils::FileNameFromUrl(class TDesC16 const &, class TBuf<256> &)
	?FixProtocolsL@PodcastUtils@@SAXAAVTDes16@@@Z @ 43 NONAME ; void PodcastUtils::FixProtocolsL(class TDes16 &)
	?GetAllShowsL@CPodcastModel@@QAEXXZ @ 44 NONAME ; void CPodcastModel::GetAllShowsL(void)
	?GetAllShowsL@CShowEngine@@QAEXAAV?$RPointerArray@VCShowInfo@@@@@Z @ 45 NONAME ; void CShowEngine::GetAllShowsL(class RPointerArray<class CShowInfo> &)
	?GetDownloadedStats@CFeedEngine@@QAEXAAI0@Z @ 46 NONAME ; void CFeedEngine::GetDownloadedStats(unsigned int &, unsigned int &)
	?GetFeedInfoByUid@CFeedEngine@@QAEPAVCFeedInfo@@I@Z @ 47 NONAME ; class CFeedInfo * CFeedEngine::GetFeedInfoByUid(unsigned int)
	?GetMimeType@CShowEngine@@QAEXABVTDesC16@@AAVTDes16@@@Z @ 48 NONAME ; void CShowEngine::GetMimeType(class TDesC16 const &, class TDes16 &)
	?GetNewShowsL@CPodcastModel@@QAEXXZ @ 49 NONAME ; void CPodcastModel::GetNewShowsL(void)
	?GetNewShowsL@CShowEngine@@QAEXAAV?$RPointerArray@VCShowInfo@@@@@Z @ 50 NONAME ; void CShowEngine::GetNewShowsL(class RPointerArray<class CShowInfo> &)
	?GetNextShowByTrackL@CShowEngine@@QAEPAVCShowInfo@@PAV2@@Z @ 51 NONAME ; class CShowInfo * CShowEngine::GetNextShowByTrackL(class CShowInfo *)
	?GetNumDownloadingShows@CShowEngine@@QAEHXZ @ 52 NONAME ; int CShowEngine::GetNumDownloadingShows(void)
	?GetSearchResults@CFeedEngine@@QAEABV?$RPointerArray@VCFeedInfo@@@@XZ @ 53 NONAME ; class RPointerArray<class CFeedInfo> const & CFeedEngine::GetSearchResults(void)
	?GetShowByUidL@CShowEngine@@QAEPAVCShowInfo@@I@Z @ 54 NONAME ; class CShowInfo * CShowEngine::GetShowByUidL(unsigned int)
	?GetShowsByFeedL@CPodcastModel@@QAEXI@Z @ 55 NONAME ; void CPodcastModel::GetShowsByFeedL(unsigned int)
	?GetShowsByFeedL@CShowEngine@@QAEXAAV?$RPointerArray@VCShowInfo@@@@I@Z @ 56 NONAME ; void CShowEngine::GetShowsByFeedL(class RPointerArray<class CShowInfo> &, unsigned int)
	?GetShowsDownloadedL@CPodcastModel@@QAEXXZ @ 57 NONAME ; void CPodcastModel::GetShowsDownloadedL(void)
	?GetShowsDownloadedL@CShowEngine@@QAEXAAV?$RPointerArray@VCShowInfo@@@@@Z @ 58 NONAME ; void CShowEngine::GetShowsDownloadedL(class RPointerArray<class CShowInfo> &)
	?GetShowsDownloadingL@CPodcastModel@@QAEXXZ @ 59 NONAME ; void CPodcastModel::GetShowsDownloadingL(void)
	?GetShowsDownloadingL@CShowEngine@@QAEXAAV?$RPointerArray@VCShowInfo@@@@@Z @ 60 NONAME ; void CShowEngine::GetShowsDownloadingL(class RPointerArray<class CShowInfo> &)
	?GetSortedFeeds@CFeedEngine@@QAEABV?$RPointerArray@VCFeedInfo@@@@XZ @ 61 NONAME ; class RPointerArray<class CFeedInfo> const & CFeedEngine::GetSortedFeeds(void)
	?GetStatsByFeed@CFeedEngine@@QAEXIAAI0@Z @ 62 NONAME ; void CFeedEngine::GetStatsByFeed(unsigned int, unsigned int &, unsigned int &)
	?IAPIds@CPodcastModel@@QAEAAV?$RArray@VTPodcastIAPItem@@@@XZ @ 63 NONAME ; class RArray<class TPodcastIAPItem> & CPodcastModel::IAPIds(void)
	?IAPNames@CPodcastModel@@QAEPAVCDesC16ArrayFlat@@XZ @ 64 NONAME ; class CDesC16ArrayFlat * CPodcastModel::IAPNames(void)
	?ImageFileName@CFeedInfo@@QBEABVTDesC16@@XZ @ 65 NONAME ; class TDesC16 const & CFeedInfo::ImageFileName(void) const
	?ImageHandler@CPodcastModel@@QAEAAVCImageHandler@@XZ @ 66 NONAME ; class CImageHandler & CPodcastModel::ImageHandler(void)
	?ImageUrl@CFeedInfo@@QBEABVTDesC16@@XZ @ 67 NONAME ; class TDesC16 const & CFeedInfo::ImageUrl(void) const
	?ImportFeedsL@CFeedEngine@@QAEXABVTDesC16@@@Z @ 68 NONAME ; void CFeedEngine::ImportFeedsL(class TDesC16 const &)
	?IsFirstStartup@CPodcastModel@@QAEHXZ @ 69 NONAME ; int CPodcastModel::IsFirstStartup(void)
	?LastError@CFeedInfo@@QBEHXZ @ 70 NONAME ; int CFeedInfo::LastError(void) const
	?LastError@CShowInfo@@QBEHXZ @ 71 NONAME ; int CShowInfo::LastError(void) const
	?LastUpdated@CFeedInfo@@QBE?AVTTime@@XZ @ 72 NONAME ; class TTime CFeedInfo::LastUpdated(void) const
	?Link@CFeedInfo@@QBEABVTDesC16@@XZ @ 73 NONAME ; class TDesC16 const & CFeedInfo::Link(void) const
	?LoadFileAndScaleL@CImageHandler@@QAEXPAVCFbsBitmap@@ABV?$TBuf@$0BAA@@@ABVTSize@@AAVMImageHandlerCallback@@IH@Z @ 74 NONAME ; void CImageHandler::LoadFileAndScaleL(class CFbsBitmap *, class TBuf<256> const &, class TSize const &, class MImageHandlerCallback &, unsigned int, int)
	?MarkSelectionPlayed@CPodcastModel@@QAEXXZ @ 75 NONAME ; void CPodcastModel::MarkSelectionPlayed(void)
	?MetaDataReader@CShowEngine@@QAEAAVCMetaDataReader@@XZ @ 76 NONAME ; class CMetaDataReader & CShowEngine::MetaDataReader(void)
	?NewL@CFeedInfo@@SAPAV1@XZ @ 77 NONAME ; class CFeedInfo * CFeedInfo::NewL(void)
	?Url@CShowInfo@@QBEABVTDesC16@@XZ @ 78 NONAME ; class TDesC16 const & CShowInfo::Url(void) const	
	?NewL@CPodcastModel@@SAPAV1@XZ @ 79 NONAME ; class CPodcastModel * CPodcastModel::NewL(void)
	?NewL@CShowEngine@@SAPAV1@AAVCPodcastModel@@@Z @ 80 NONAME ; class CShowEngine * CShowEngine::NewL(class CPodcastModel &)
	?NewL@CShowInfo@@SAPAV1@I@Z @ 81 NONAME ; class CShowInfo * CShowInfo::NewL(unsigned int)
	?NewLC@CFeedInfo@@SAPAV1@XZ @ 82 NONAME ; class CFeedInfo * CFeedInfo::NewLC(void)
	?XMLEncode@PodcastUtils@@SAXAAVTDes16@@@Z @ 83 NONAME ; void PodcastUtils::XMLEncode(class TDes16 &)
	?NewLC@CShowInfo@@SAPAV1@I@Z @ 84 NONAME ; class CShowInfo * CShowInfo::NewLC(unsigned int)
	?NotifyShowListUpdatedL@CShowEngine@@QAEXXZ @ 85 NONAME ; void CShowEngine::NotifyShowListUpdatedL(void)
	?OpmlParsingComplete@CFeedEngine@@QAEXHI@Z @ 86 NONAME ; void CFeedEngine::OpmlParsingComplete(int, unsigned int)
	?Pause@CSoundEngine@@QAEXH@Z @ 87 NONAME ; void CSoundEngine::Pause(int)
	?Play@CSoundEngine@@QAEXXZ @ 88 NONAME ; void CSoundEngine::Play(void)
	?PlayPausePodcastL@CPodcastModel@@QAEXPAVCShowInfo@@H@Z @ 89 NONAME ; void CPodcastModel::PlayPausePodcastL(class CShowInfo *, int)
	?PlayState@CShowInfo@@QBE?AW4TPlayState@@XZ @ 90 NONAME ; enum TPlayState CShowInfo::PlayState(void) const
	?PlayTime@CShowInfo@@QBEIXZ @ 91 NONAME ; unsigned int CShowInfo::PlayTime(void) const
	?PlayingPodcast@CPodcastModel@@QAEPAVCShowInfo@@XZ @ 92 NONAME ; class CShowInfo * CPodcastModel::PlayingPodcast(void)
	?Position@CShowInfo@@QBE?AVTTimeIntervalMicroSeconds@@XZ @ 93 NONAME ; class TTimeIntervalMicroSeconds CShowInfo::Position(void) const
	?Position@CSoundEngine@@QAE?AVTTimeIntervalMicroSeconds@@XZ @ 94 NONAME ; class TTimeIntervalMicroSeconds CSoundEngine::Position(void)
	?PubDate@CShowInfo@@QBE?BVTTime@@XZ @ 95 NONAME ; class TTime const CShowInfo::PubDate(void) const
	?RemoveAllDownloads@CShowEngine@@QAEXXZ @ 96 NONAME ; void CShowEngine::RemoveAllDownloads(void)
	?RemoveAllFormatting@PodcastUtils@@SAXAAVTDes16@@@Z @ 97 NONAME ; void PodcastUtils::RemoveAllFormatting(class TDes16 &)
	?RemoveDownloadL@CShowEngine@@QAEHI@Z @ 98 NONAME ; int CShowEngine::RemoveDownloadL(unsigned int)
	?RemoveFeedL@CFeedEngine@@QAEXI@Z @ 99 NONAME ; void CFeedEngine::RemoveFeedL(unsigned int)
	?RemoveObserver@CFeedEngine@@QAEXPAVMFeedEngineObserver@@@Z @ 100 NONAME ; void CFeedEngine::RemoveObserver(class MFeedEngineObserver *)
	?RemoveObserver@CShowEngine@@QAEXPAVMShowEngineObserver@@@Z @ 101 NONAME ; void CShowEngine::RemoveObserver(class MShowEngineObserver *)
	?ReplaceChar@PodcastUtils@@SAXAAVTDes16@@II@Z @ 102 NONAME ; void PodcastUtils::ReplaceChar(class TDes16 &, unsigned int, unsigned int)
	?ReplaceString@PodcastUtils@@SAXAAVTDes16@@ABVTDesC16@@1@Z @ 103 NONAME ; void PodcastUtils::ReplaceString(class TDes16 &, class TDesC16 const &, class TDesC16 const &)
	?ResumeDownloadsL@CShowEngine@@QAEXXZ @ 104 NONAME ; void CShowEngine::ResumeDownloadsL(void)
	?SNAPIds@CPodcastModel@@QAEAAV?$RArray@VTPodcastIAPItem@@@@XZ @ 105 NONAME ; class RArray<class TPodcastIAPItem> & CPodcastModel::SNAPIds(void)
	?SNAPNames@CPodcastModel@@QAEPAVCDesC16ArrayFlat@@XZ @ 106 NONAME ; class CDesC16ArrayFlat * CPodcastModel::SNAPNames(void)
	?SQLEncode@PodcastUtils@@SAXAAVTDes16@@@Z @ 107 NONAME ; void PodcastUtils::SQLEncode(class TDes16 &)
	?SaveSettingsL@CSettingsEngine@@QAEXXZ @ 108 NONAME ; void CSettingsEngine::SaveSettingsL(void)
	?ScaledBitmap@CImageHandler@@QAEPAVCFbsBitmap@@XZ @ 109 NONAME ; class CFbsBitmap * CImageHandler::ScaledBitmap(void)
	?SearchForFeedL@CFeedEngine@@QAEXAAVTDesC16@@@Z @ 110 NONAME ; void CFeedEngine::SearchForFeedL(class TDesC16 &)
	?SetActiveFeedInfo@CPodcastModel@@QAEXPAVCFeedInfo@@@Z @ 111 NONAME ; void CPodcastModel::SetActiveFeedInfo(class CFeedInfo *)
	?SetBaseDir@CSettingsEngine@@QAEXAAV?$TBuf@$0BAA@@@@Z @ 112 NONAME ; void CSettingsEngine::SetBaseDir(class TBuf<256> &)
	?SetBuildDate@CFeedInfo@@QAEXVTTime@@@Z @ 113 NONAME ; void CFeedInfo::SetBuildDate(class TTime)
	?SetCustomTitle@CFeedInfo@@QAEXXZ @ 114 NONAME ; void CFeedInfo::SetCustomTitle(void)
	?SetDescriptionL@CFeedInfo@@QAEXABVTDesC16@@@Z @ 115 NONAME ; void CFeedInfo::SetDescriptionL(class TDesC16 const &)
	?SetDescriptionL@CShowInfo@@QAEXABVTDesC16@@@Z @ 116 NONAME ; void CShowInfo::SetDescriptionL(class TDesC16 const &)
	?SetDownloadAutomatically@CSettingsEngine@@QAEXH@Z @ 117 NONAME ; void CSettingsEngine::SetDownloadAutomatically(int)
	?SetDownloadState@CShowInfo@@QAEXW4TDownloadState@@@Z @ 118 NONAME ; void CShowInfo::SetDownloadState(enum TDownloadState)
	?SetDownloadSuspended@CSettingsEngine@@QAEXH@Z @ 119 NONAME ; void CSettingsEngine::SetDownloadSuspended(int)
	?SetFeedIcon@CFeedInfo@@QAEXPAVCFbsBitmap@@@Z @ 120 NONAME ; void CFeedInfo::SetFeedIcon(class CFbsBitmap *)
	?SetFeedUid@CShowInfo@@QAEXI@Z @ 121 NONAME ; void CShowInfo::SetFeedUid(unsigned int)
	?SetFileNameL@CShowInfo@@QAEXABVTDesC16@@@Z @ 122 NONAME ; void CShowInfo::SetFileNameL(class TDesC16 const &)
	?SetImageFileNameL@CFeedInfo@@QAEXABVTDesC16@@@Z @ 123 NONAME ; void CFeedInfo::SetImageFileNameL(class TDesC16 const &)
	?SetImageUrlL@CFeedInfo@@QAEXABVTDesC16@@@Z @ 124 NONAME ; void CFeedInfo::SetImageUrlL(class TDesC16 const &)
	?SetLastError@CFeedInfo@@QAEXH@Z @ 125 NONAME ; void CFeedInfo::SetLastError(int)
	?SetLastError@CShowInfo@@QAEXH@Z @ 126 NONAME ; void CShowInfo::SetLastError(int)
	?SetLastUpdated@CFeedInfo@@QAEXVTTime@@@Z @ 127 NONAME ; void CFeedInfo::SetLastUpdated(class TTime)
	?SetLinkL@CFeedInfo@@QAEXABVTDesC16@@@Z @ 128 NONAME ; void CFeedInfo::SetLinkL(class TDesC16 const &)
	?SetPlayState@CShowInfo@@QAEXW4TPlayState@@@Z @ 129 NONAME ; void CShowInfo::SetPlayState(enum TPlayState)
	?SetPlayTime@CShowInfo@@QAEXI@Z @ 130 NONAME ; void CShowInfo::SetPlayTime(unsigned int)
	?SetPlayingPodcast@CPodcastModel@@QAEXPAVCShowInfo@@@Z @ 131 NONAME ; void CPodcastModel::SetPlayingPodcast(class CShowInfo *)
	?SetPosition@CShowInfo@@QAEXVTTimeIntervalMicroSeconds@@@Z @ 132 NONAME ; void CShowInfo::SetPosition(class TTimeIntervalMicroSeconds)
	?SetPosition@CSoundEngine@@QAEXI@Z @ 133 NONAME ; void CSoundEngine::SetPosition(unsigned int)
	?SetPubDate@CShowInfo@@QAEXVTTime@@@Z @ 134 NONAME ; void CShowInfo::SetPubDate(class TTime)
	?SetShowSize@CShowInfo@@QAEXI@Z @ 135 NONAME ; void CShowInfo::SetShowSize(unsigned int)
	?SetShowType@CShowInfo@@QAEXW4TShowType@@@Z @ 136 NONAME ; void CShowInfo::SetShowType(enum TShowType)
	?SetSpecificIAP@CSettingsEngine@@QAEXH@Z @ 137 NONAME ; void CSettingsEngine::SetSpecificIAP(int)
	?SetTitleL@CFeedInfo@@QAEXABVTDesC16@@@Z @ 138 NONAME ; void CFeedInfo::SetTitleL(class TDesC16 const &)
	?SetTitleL@CShowInfo@@QAEXABVTDesC16@@@Z @ 139 NONAME ; void CShowInfo::SetTitleL(class TDesC16 const &)
	?SetTrackNo@CShowInfo@@QAEXI@Z @ 140 NONAME ; void CShowInfo::SetTrackNo(unsigned int)
	?SetUid@CShowInfo@@QAEXI@Z @ 141 NONAME ; void CShowInfo::SetUid(unsigned int)
	?SetUpdateAutomatically@CSettingsEngine@@QAEXW4TAutoUpdateSetting@@@Z @ 142 NONAME ; void CSettingsEngine::SetUpdateAutomatically(enum TAutoUpdateSetting)
	?SetUpdateFeedInterval@CSettingsEngine@@QAEXH@Z @ 143 NONAME ; void CSettingsEngine::SetUpdateFeedInterval(int)
	?SetUpdateFeedTime@CSettingsEngine@@QAEXVTTime@@@Z @ 144 NONAME ; void CSettingsEngine::SetUpdateFeedTime(class TTime)
	?SetUrlL@CFeedInfo@@QAEXABVTDesC16@@@Z @ 145 NONAME ; void CFeedInfo::SetUrlL(class TDesC16 const &)
	?SetUrlL@CShowInfo@@QAEXABVTDesC16@@@Z @ 146 NONAME ; void CShowInfo::SetUrlL(class TDesC16 const &)
	?SettingsEngine@CPodcastModel@@QAEAAVCSettingsEngine@@XZ @ 147 NONAME ; class CSettingsEngine & CPodcastModel::SettingsEngine(void)
	?ShowDownloading@CShowEngine@@QAEPAVCShowInfo@@XZ @ 148 NONAME ; class CShowInfo * CShowEngine::ShowDownloading(void)
	?ShowEngine@CPodcastModel@@QAEAAVCShowEngine@@XZ @ 149 NONAME ; class CShowEngine & CPodcastModel::ShowEngine(void)
	?ShowSize@CShowInfo@@QBEIXZ @ 150 NONAME ; unsigned int CShowInfo::ShowSize(void) const
	?ShowType@CShowInfo@@QBE?AW4TShowType@@XZ @ 151 NONAME ; enum TShowType CShowInfo::ShowType(void) const
	?SoundEngine@CPodcastModel@@QAEAAVCSoundEngine@@XZ @ 152 NONAME ; class CSoundEngine & CPodcastModel::SoundEngine(void)
	?SpecificIAP@CSettingsEngine@@QAEHXZ @ 153 NONAME ; int CSettingsEngine::SpecificIAP(void)
	?State@CSoundEngine@@QAE?AW4TSoundEngineState@@XZ @ 154 NONAME ; enum TSoundEngineState CSoundEngine::State(void)
	?Stop@CSoundEngine@@QAEXH@Z @ 155 NONAME ; void CSoundEngine::Stop(int)
	?SuspendDownloads@CShowEngine@@QAEXXZ @ 156 NONAME ; void CShowEngine::SuspendDownloads(void)
	?Title@CFeedInfo@@QBEABVTDesC16@@XZ @ 157 NONAME ; class TDesC16 const & CFeedInfo::Title(void) const
	?Title@CShowInfo@@QBEABVTDesC16@@XZ @ 158 NONAME ; class TDesC16 const & CShowInfo::Title(void) const
	?TrackNo@CShowInfo@@QBEIXZ @ 159 NONAME ; unsigned int CShowInfo::TrackNo(void) const
	?Uid@CFeedInfo@@QBEIXZ @ 160 NONAME ; unsigned int CFeedInfo::Uid(void) const
	?Uid@CShowInfo@@QBEIXZ @ 161 NONAME ; unsigned int CShowInfo::Uid(void) const
	?UpdateAllFeedsL@CFeedEngine@@QAEXH@Z @ 162 NONAME ; void CFeedEngine::UpdateAllFeedsL(int)
	?UpdateAutomatically@CSettingsEngine@@QAE?AW4TAutoUpdateSetting@@XZ @ 163 NONAME ; enum TAutoUpdateSetting CSettingsEngine::UpdateAutomatically(void)
	?UpdateFeed@CFeedEngine@@QAEXPAVCFeedInfo@@@Z @ 164 NONAME ; void CFeedEngine::UpdateFeed(class CFeedInfo *)
	?UpdateFeedInterval@CSettingsEngine@@QAEHXZ @ 165 NONAME ; int CSettingsEngine::UpdateFeedInterval(void)
	?UpdateFeedL@CFeedEngine@@QAEHI@Z @ 166 NONAME ; int CFeedEngine::UpdateFeedL(unsigned int)
	?UpdateFeedTime@CSettingsEngine@@QAE?AVTTime@@XZ @ 167 NONAME ; class TTime CSettingsEngine::UpdateFeedTime(void)
	?UpdateIAPListL@CPodcastModel@@QAEXXZ @ 168 NONAME ; void CPodcastModel::UpdateIAPListL(void)
	?UpdateSNAPListL@CPodcastModel@@QAEXXZ @ 169 NONAME ; void CPodcastModel::UpdateSNAPListL(void)
	?UpdateShow@CShowEngine@@QAEXAAVCShowInfo@@@Z @ 170 NONAME ; void CShowEngine::UpdateShow(class CShowInfo &)
	?Url@CFeedInfo@@QBEABVTDesC16@@XZ @ 171 NONAME ; class TDesC16 const & CFeedInfo::Url(void) const
	?NewL@CImageHandler@@SAPAV1@AAVRFs@@AAVCPodcastModel@@@Z @ 172 NONAME ; class CImageHandler * CImageHandler::NewL(class RFs &, class CPodcastModel &)
	?NewLC@CImageHandler@@SAPAV1@AAVRFs@@AAVCPodcastModel@@@Z @ 173 NONAME ; class CImageHandler * CImageHandler::NewLC(class RFs &, class CPodcastModel &)
